---
name: 1. Introduction
route: /
---
<h3 align="center" >
  <a href="https://travis-med-ai.github.io">
    <img align="center" alt="Travis AI" src="https://raw.githubusercontent.com/Travis-Med-AI/med-ai/master/logo.svg" width="60" />
  </a>
</h3>

<h2 align="center">
  Travis Med AI
</h2>

<h3 align="center">
  Simplified AI in a clinical Setting
</h3>
  Travis Med AI is an open source AI framework based on Docker to help streamline machine learning integration into the clinic.
<h3 align="center">
  <a href="https://github.com/travis-med-ai/med-ai/blob/master/LICENSE.md">
    <img src="https://img.shields.io/badge/license-ASL-blue.svg" alt="Travis Med AI is released under the MIT license." />
  </a>
  <a href="https://travis-med-ai.github.io/contributing/how-to-contribute/">
    <img src="https://img.shields.io/badge/PRs-welcome-brightgreen.svg" alt="PRs welcome!" />
  </a>
</h3>

<h3 align="center">
  <a href="https://travis-med-ai.github.io/installation">Installation/Quickstart</a>
  <span> · </span>
  <a href="https://travis-med-ai.github.io/tutorial">Tutorial</a>
  <span> · </span>
  <a href="https://travis-med-ai.github.io/models">Models</a>
  <span> · </span>
  <a href="https://travis-med-ai.github.io/contributing/how-to-contribute/">Contribute</a>
</h3>